+++
title = "Source block with caption"
tags = ["src-block", "caption"]
draft = false
+++

```makefile
prefix = /dir/where/you/want/to/install/org # Default: /usr/share
```

<div class="src-block-caption">
  <span class="src-block-number">Code Snippet 1</span>:
  Prefix value in <code>local.mk</code>
</div>

```emacs-lisp
(message "hello")
```

<div class="src-block-caption">
  <span class="src-block-number">Code Snippet 2</span>:
  Hello &#x2014; Caption with em-dash &#x2013; and &#x2013; en-dash
</div>
